==> nextcloud-app-tasks-0.13.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/id.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Penting",
    "Today" : "Hari Ini",
    "Week" : "Minggu",
    "All" : "Semua",
    "Current" : "Saat ini",
    "Completed" : "Selesai",
    "Tasks" : "Tugas",
    "The Tasks app for Nextcloud" : "Aplikasi Tugas untuk Nextcloud",
    "New List" : "Daftar Baru",
    "Cancel" : "Batal",
    "Save" : "Simpan",
    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "can edit" : "dapat menyunting",
    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
    "Edit" : "Sunting",
    "Copy private link" : "Salin tautan privat",
    "Download" : "Unduh",
    "Delete" : "Hapus",
    "Unshare" : "Batalkan berbagi",
    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
    "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
    "Hidden" : "Sembunyi",
    "Visible" : "Tampak",
    "Automatic" : "Otomatis",
    "Due date" : "Tenggat",
    "Last modified" : "Terakhir diubah",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tugas Diselesaikan"],
    "Tomorrow" : "Besok",
    "Set start date" : "Atur tanggal mulai",
    "Set due date" : "Atur tanggal jatuh tempo",
    "All day" : "Sepanjang hari",
    "Add this as a new category" : "Tambah sebagai kategori baru",
    "Task not found!" : "Tugas tidak ditemukan!",
    "An error occurred" : "Terjadi kesalahan"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/id.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Penting",
    "Today" : "Hari Ini",
    "Week" : "Minggu",
    "All" : "Semua",
    "Current" : "Saat ini",
    "Completed" : "Selesai",
    "Tasks" : "Tugas",
    "The Tasks app for Nextcloud" : "Aplikasi Tugas untuk Nextcloud",
    "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
    "Hidden" : "Sembunyi",
    "Visible" : "Tampak",
    "Automatic" : "Otomatis",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "Can edit" : "Can edit",
    "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
    "Edit" : "Sunting",
    "Copy private link" : "Salin tautan privat",
    "Copied" : "Tersalin",
    "Export" : "Ekspor",
    "Delete" : "Hapus",
    "Unshare" : "Batalkan berbagi",
    "Save" : "Simpan",
    "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
    "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
    "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
    "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
    "Name" : "Nama",
    "Deleted" : "Dihapus",
    "Restore" : "Pulihkan",
    "Delete permanently" : "Hapus secara permanen",
    "Empty trash bin" : "Kosongkan tempat sampah",
    "Untitled task" : "Tugas tanpa judul",
    "Untitled event" : "Acara tanpa judul",
    "Due date" : "Tenggat",
    "Last modified" : "Terakhir diubah",
    "[Today]" : "[Hari ini]",
    "Cancel" : "Batal",
    "Close" : "Tutup",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tugas Diselesaikan"],
    "Tomorrow" : "Besok",
    "New List" : "Daftar Baru",
    "All day" : "Sepanjang hari",
    "Details" : "Detail",
    "Notes" : "Catatan",
    "Reminders" : "Pengingat",
    "Repeat" : "Ulang",
    "Task not found!" : "Tugas tidak ditemukan!",
    "[Starts today]" : "[Dimulai hari ini]",
    "Set start date" : "Atur tanggal mulai",
    "Set due date" : "Atur tanggal jatuh tempo",
    "An error occurred" : "Terjadi kesalahan"
},
"nplurals=1; plural=0;");
